@@ -8,8 +8,7 @@ from archipelagos.common.data.filestore import FileStoreResponse, FileStoreReque
 from archipelagos.common.data.filestore import FileMetadataRequest, FileMetadataResponse
 from archipelagos.common.data.timeseries import TimeSeriesRequest, TimeSeriesResponse
 from archipelagos.common.data.timeseries import TimeSeriesMetadataRequest, TimeSeriesMetadataResponse
-from archipelagos.common.platform import HttpConstants
-from archipelagos.common.data import PYTHON_CLIENT
+from archipelagos.common.platform import HttpConstants, ClientType
 
 import io
 import pandas as pd
@@ -130,7 +129,7 @@ class Archipelagos:
         if isinstance(port, int):
             base_url = "{0}:{1}".format(base_url, port)
 
-        query_params = {HttpConstants.CLIENT_TYPE_PARAMETER: PYTHON_CLIENT}
+        query_params = {HttpConstants.CLIENT_TYPE_PARAMETER: ClientType.PYTHON_CLIENT}
 
         for param in params:
             value = params[param]
