@@ -14,7 +14,7 @@ from archipelagos.common.protobuf.common.data import DataEntry_pb2
 from archipelagos.common.protobuf.common import Timestamp_pb2
 from archipelagos.common.data import _valid_feature_value, _feature_value_equals
 from archipelagos.common.data import _get_feature_value, _get_feature_value_from_proto
-from archipelagos.common.data import PYTHON_CLIENT
+from archipelagos.common.platform import ClientType
 
 from archipelagos.common.data import Frequency, is_valid_token
 
@@ -835,6 +835,7 @@ class CollectionMetadataRequest:
         self._source = source
         self._code = code
         self._cid = cid
+        self._client_type = ClientType.PYTHON_CLIENT
 
     @property
     def api_key(self) -> str:
@@ -893,6 +894,16 @@ class CollectionMetadataRequest:
         """
         return self._cid
 
+    @property
+    def client_type(self) -> str:
+        """
+        Returns the type of client that sent this request.
+
+        :return: The type of client that sent this request.
+        :rtype: str
+        """
+        return self._client_type
+
     @staticmethod
     def deserialize(serialized: bytes) -> CollectionMetadataRequest:
         """
@@ -933,6 +944,7 @@ class CollectionMetadataRequest:
         self._source = metadata_request.source
         self._code = metadata_request.code
         self._cid = metadata_request.id
+        self._client_type = metadata_request.clientType
 
     def _write_proto_object(self) -> CollectionMetadataRequest_pb2.CollectionMetadataRequest:
         """
@@ -946,7 +958,7 @@ class CollectionMetadataRequest:
         request.source = self._source
         request.code = self._code
         request.id = self._cid
-        request.clientType = PYTHON_CLIENT
+        request.clientType = self._client_type
 
         return request
 
@@ -1225,6 +1237,7 @@ class CollectionRequest:
         self._features = features
         self._max_size = max_size
         self._filters = filters
+        self._client_type = ClientType.PYTHON_CLIENT
 
     @property
     def api_key(self) -> str or None:
@@ -1309,6 +1322,16 @@ class CollectionRequest:
         """
         return self._filters
 
+    @property
+    def client_type(self) -> str:
+        """
+        Returns the type of client that sent this request.
+
+        :return: The type of client that sent this request.
+        :rtype: str
+        """
+        return self._client_type
+
     @staticmethod
     def deserialize(serialized: bytes):
         """
@@ -1362,6 +1385,7 @@ class CollectionRequest:
 
         self._max_size = request.maxSize
         self._filters = request.filters
+        self._client_type = request.clientType
 
     def _write_proto_object(self) -> CollectionRequest_pb2.CollectionRequest:
         """
@@ -1386,7 +1410,7 @@ class CollectionRequest:
 
         request.maxSize = self._max_size
         request.filters.update(self._filters)
-        request.clientType = PYTHON_CLIENT
+        request.clientType = ClientType.PYTHON_CLIENT
 
         return request
 
