@@ -14,7 +14,7 @@ from archipelagos.common.protobuf.common import Timestamp_pb2
 from archipelagos.common.data import _valid_feature_value, _feature_value_equals
 from archipelagos.common.data import _get_feature_value, _get_feature_value_from_proto
 from archipelagos.common.data import Frequency, is_valid_token
-from archipelagos.common.data import PYTHON_CLIENT
+from archipelagos.common.platform import ClientType
 
 import array
 from typing import Dict, List, Tuple, Any
@@ -1008,6 +1008,7 @@ class TimeSeriesMetadataRequest:
         self._source = source
         self._code = code
         self._ts_id = ts_id
+        self._client_type = ClientType.PYTHON_CLIENT
 
     @property
     def api_key(self) -> str:
@@ -1065,6 +1066,16 @@ class TimeSeriesMetadataRequest:
         """
         return self._ts_id
 
+    @property
+    def client_type(self) -> str:
+        """
+        Returns the type of client that sent this request.
+
+        :return: The type of client that sent this request.
+        :rtype: str
+        """
+        return self._client_type
+
     @staticmethod
     def deserialize(serialized: bytes) -> TimeSeriesMetadataRequest:
         """
@@ -1103,6 +1114,7 @@ class TimeSeriesMetadataRequest:
         self._source = metadata_request.source
         self._code = metadata_request.code
         self._ts_id = metadata_request.id
+        self._client_type = metadata_request.clientType
 
     def _write_proto_object(self) -> TimeSeriesMetadataRequest_pb2.TimeSeriesMetadataRequest:
         """
@@ -1116,7 +1128,7 @@ class TimeSeriesMetadataRequest:
         request.source = self._source
         request.code = self._code
         request.id = self._ts_id
-        request.clientType = PYTHON_CLIENT
+        request.clientType = self._client_type
 
         return request
 
@@ -1420,6 +1432,7 @@ class TimeSeriesRequest:
         self._max_size = max_size
         self._ascending = ascending
         self._filters = filters
+        self._client_type = ClientType.PYTHON_CLIENT
 
     @property
     def api_key(self) -> str or None:
@@ -1534,6 +1547,16 @@ class TimeSeriesRequest:
         """
         return self._filters
 
+    @property
+    def client_type(self) -> str:
+        """
+        Returns the type of client that sent this request.
+
+        :return: The type of client that sent this request.
+        :rtype: str
+        """
+        return self._client_type
+
     @staticmethod
     def deserialize(serialized: bytes) -> TimeSeriesRequest:
         """
@@ -1615,6 +1638,8 @@ class TimeSeriesRequest:
                 value = request.filters[key]
                 self._filters[key] = value
 
+        self._client_type = request.clientType
+
     def _write_proto_object(self) -> TimeSeriesRequest_pb2.TimeSeriesRequest:
         """
         Builds a Protobuf object containing the serialised state of this.
@@ -1657,7 +1682,7 @@ class TimeSeriesRequest:
         request.maxSize = self._max_size
         request.ascending = self._ascending
         request.filters.update(self._filters)
-        request.clientType = PYTHON_CLIENT
+        request.clientType = self._client_type
 
         return request
 
