@@ -95,3 +95,16 @@ class HttpConstants:
     FILE_STORE_METADATA_REQUEST = "file-store-metadata"
     FILE_METADATA_REQUEST = "file-metadata"
     CLIENT_TYPE_PARAMETER = "archipelagos_client_type"
+
+
+class ClientType:
+    """
+    The types of Client supported in the platform.
+    """
+    PYTHON_CLIENT = "Python Client"
+    JAVA_CLIENT = "Java Client"
+    CSHARP_CLIENT = "C# Client"
+    HTTP_CLIENT = "HTTP Client"
+    HTTP_PYTHON_CLIENT = "HTTP Client (Python)"
+    HTTP_JAVA_CLIENT = "HTTP Client (Java)"
+    HTTP_CSHARP_CLIENT = "HTTP Client (C#)"
